16.74. cdist-type__iptables_apply(7) — cdist 4.11.0 documentation

# 16.74. cdist-type__iptables_apply(7)

## 16.74.1. NAME

cdist-type__iptables_apply - Apply the rules

## 16.74.2. DESCRIPTION

This cdist type deploys an init script that triggers the configured rules and also re-applies them on configuration.

## 16.74.3. REQUIRED PARAMETERS

None

## 16.74.4. OPTIONAL PARAMETERS

None

## 16.74.5. EXAMPLES

None (__iptables_apply is used by __iptables_rule)

## 16.74.6. SEE ALSO

cdist-type__iptables_rule(7), iptables(8)

## 16.74.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.74.8. COPYING

Copyright (C) 2013 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.